@@ -97,6 +97,9 @@ new FargateToSqs(this, "test_construct", new FargateToSqsProps.Builder()
 |queueUrlEnvironmentVariableName?|string|Optional Name for the container environment variable set to the URL of the queue. Default: SQS_QUEUE_URL |
 |queueArnEnvironmentVariableName?|string|Optional Name for the container environment variable set to the arn of the queue. Default: SQS_QUEUE_ARN |
 |queuePermissions?|`string[]`|Optional queue permissions to grant to the Fargate service. One or more of the following may be specified: `Read`,`Write`. Default is `Write`|
+|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SQS Queue with.|
+|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with.|
 
 ## Pattern Properties
 
@@ -155,6 +158,7 @@ from ._jsii import *
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_ecs
+import aws_cdk.aws_kms
 import aws_cdk.aws_sqs
 import constructs
 
@@ -176,6 +180,9 @@ class FargateToSqs(
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
         existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
@@ -199,6 +206,9 @@ class FargateToSqs(
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
         :param ecr_image_version: The version of the image to use from the repository. Default: - 'latest'
         :param ecr_repository_arn: The arn of an ECR Repository containing the image to use to generate the containers. format: arn:aws:ecr:[region]:[account number]:repository/[Repository Name]
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_container_definition_object: -
         :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
         :param existing_queue_obj: Existing instance of SQS queue object, Providing both this and queueProps will cause an error. Default: - Default props are used
@@ -224,6 +234,9 @@ class FargateToSqs(
                 deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
                 ecr_image_version: typing.Optional[builtins.str] = None,
                 ecr_repository_arn: typing.Optional[builtins.str] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
                 existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
                 existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
                 existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
@@ -249,6 +262,9 @@ class FargateToSqs(
             deploy_dead_letter_queue=deploy_dead_letter_queue,
             ecr_image_version=ecr_image_version,
             ecr_repository_arn=ecr_repository_arn,
+            enable_encryption_with_customer_managed_key=enable_encryption_with_customer_managed_key,
+            encryption_key=encryption_key,
+            encryption_key_props=encryption_key_props,
             existing_container_definition_object=existing_container_definition_object,
             existing_fargate_service_object=existing_fargate_service_object,
             existing_queue_obj=existing_queue_obj,
@@ -302,6 +318,9 @@ class FargateToSqs(
         "deploy_dead_letter_queue": "deployDeadLetterQueue",
         "ecr_image_version": "ecrImageVersion",
         "ecr_repository_arn": "ecrRepositoryArn",
+        "enable_encryption_with_customer_managed_key": "enableEncryptionWithCustomerManagedKey",
+        "encryption_key": "encryptionKey",
+        "encryption_key_props": "encryptionKeyProps",
         "existing_container_definition_object": "existingContainerDefinitionObject",
         "existing_fargate_service_object": "existingFargateServiceObject",
         "existing_queue_obj": "existingQueueObj",
@@ -327,6 +346,9 @@ class FargateToSqsProps:
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
+        enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
         existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
         existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
@@ -348,6 +370,9 @@ class FargateToSqsProps:
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
         :param ecr_image_version: The version of the image to use from the repository. Default: - 'latest'
         :param ecr_repository_arn: The arn of an ECR Repository containing the image to use to generate the containers. format: arn:aws:ecr:[region]:[account number]:repository/[Repository Name]
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_container_definition_object: -
         :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
         :param existing_queue_obj: Existing instance of SQS queue object, Providing both this and queueProps will cause an error. Default: - Default props are used
@@ -365,6 +390,8 @@ class FargateToSqsProps:
             cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
         if isinstance(dead_letter_queue_props, dict):
             dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if isinstance(vpc_props, dict):
@@ -379,6 +406,9 @@ class FargateToSqsProps:
                 deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
                 ecr_image_version: typing.Optional[builtins.str] = None,
                 ecr_repository_arn: typing.Optional[builtins.str] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
                 existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
                 existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
                 existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
@@ -401,6 +431,9 @@ class FargateToSqsProps:
             check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
             check_type(argname="argument ecr_image_version", value=ecr_image_version, expected_type=type_hints["ecr_image_version"])
             check_type(argname="argument ecr_repository_arn", value=ecr_repository_arn, expected_type=type_hints["ecr_repository_arn"])
+            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
+            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
+            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
             check_type(argname="argument existing_container_definition_object", value=existing_container_definition_object, expected_type=type_hints["existing_container_definition_object"])
             check_type(argname="argument existing_fargate_service_object", value=existing_fargate_service_object, expected_type=type_hints["existing_fargate_service_object"])
             check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
@@ -428,6 +461,12 @@ class FargateToSqsProps:
             self._values["ecr_image_version"] = ecr_image_version
         if ecr_repository_arn is not None:
             self._values["ecr_repository_arn"] = ecr_repository_arn
+        if enable_encryption_with_customer_managed_key is not None:
+            self._values["enable_encryption_with_customer_managed_key"] = enable_encryption_with_customer_managed_key
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if encryption_key_props is not None:
+            self._values["encryption_key_props"] = encryption_key_props
         if existing_container_definition_object is not None:
             self._values["existing_container_definition_object"] = existing_container_definition_object
         if existing_fargate_service_object is not None:
@@ -514,6 +553,37 @@ class FargateToSqsProps:
         result = self._values.get("ecr_repository_arn")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def enable_encryption_with_customer_managed_key(
+        self,
+    ) -> typing.Optional[builtins.bool]:
+        '''If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key.
+
+        This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.
+
+        :default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        '''
+        result = self._values.get("enable_encryption_with_customer_managed_key")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+        '''An optional, imported encryption key to encrypt the SQS Queue with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+
+    @builtins.property
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+        '''Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with.
+
+        :default: - None
+        '''
+        result = self._values.get("encryption_key_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+
     @builtins.property
     def existing_container_definition_object(
         self,
